@@ -59,6 +59,6 @@ def reset(
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {"subcommand": subcommand}
 
-    base.execute_cmdline_scenarios(scenario_name, args, command_args)
+    base.execute_cmdline_scenarios([scenario_name], args, command_args)
     for driver in drivers().values():
         driver.reset()
